// src/highlight.tsx
import { useRef, useState, useCallback } from "react";

// src/hooks/use-effect-once.tsx
import { useEffect } from "react";
var useEffectOnce = (effect) => {
  useEffect(effect, []);
};

// src/highlight.tsx
import { jsx, jsxs } from "react/jsx-runtime";
function TextHighlightPopup({
  children,
  actions,
  getActionPayload = (text) => text
}) {
  const [isPopupVisible, setIsPopupVisible] = useState(false);
  const [popupPosition, setPopupPosition] = useState({ top: 0, left: 0 });
  const [selectedText, setSelectedText] = useState("");
  const containerRef = useRef(null);
  const popupRef = useRef(null);
  const calculatePopupPosition = useCallback((rect, containerRect) => {
    var _a, _b;
    const popupWidth = ((_a = popupRef.current) == null ? void 0 : _a.offsetWidth) || 0;
    const popupHeight = ((_b = popupRef.current) == null ? void 0 : _b.offsetHeight) || 0;
    let top = Math.max(0, rect.bottom - containerRect.top);
    let left = rect.left - containerRect.left + rect.width / 2;
    if (left + popupWidth > containerRect.width) {
      left = containerRect.width - popupWidth;
    } else if (left < 0) {
      left = 10;
    }
    if (top + popupHeight > containerRect.height) {
      top = rect.top - containerRect.top - popupHeight;
    } else if (top < 0) {
      top = 10;
    }
    return { top, left };
  }, []);
  const handleMouseUp = useCallback(() => {
    var _a;
    const selection = window.getSelection();
    if (selection && selection.toString().trim().length > 0) {
      const range = selection.getRangeAt(0);
      const rect = range.getBoundingClientRect();
      const containerRect = (_a = containerRef.current) == null ? void 0 : _a.getBoundingClientRect();
      if (containerRect) {
        const newPosition = calculatePopupPosition(rect, containerRect);
        setPopupPosition(newPosition);
      }
      setSelectedText(selection.toString().trim());
      setIsPopupVisible(true);
    }
  }, [calculatePopupPosition]);
  const handleActionClick = useCallback((action) => {
    const payload = getActionPayload(selectedText);
    if (action.action) {
      action.action(payload);
    } else null;
    setIsPopupVisible(false);
  }, [getActionPayload, selectedText]);
  const handleSelectionChange = useCallback(() => {
    const selection = window.getSelection();
    if (!selection || selection.toString().trim().length === 0) {
      setIsPopupVisible(false);
    }
  }, []);
  useEffectOnce(() => {
    document.addEventListener("selectionchange", handleSelectionChange, { capture: true });
    return () => document.removeEventListener("selectionchange", handleSelectionChange);
  });
  return /* @__PURE__ */ jsxs(
    "div",
    {
      ref: containerRef,
      className: "text-highlight-container relative",
      onMouseUp: handleMouseUp,
      children: [
        children,
        isPopupVisible && /* @__PURE__ */ jsx(
          "div",
          {
            ref: popupRef,
            className: "text-highlight-popup absolute transition popup",
            style: {
              top: `${popupPosition.top}px`,
              left: `${popupPosition.left}px`
            },
            children: /* @__PURE__ */ jsx("div", { className: "flex space-x-2 bg-transparent p-2", "aria-label": "Text highlight actions", children: actions.slice(0, 3).map((action) => /* @__PURE__ */ jsx("div", { className: "action-container bg-white rounded shadow flex flex-row items-center p-2", children: /* @__PURE__ */ jsxs(
              "button",
              {
                type: "button",
                onClick: () => handleActionClick(action),
                className: "button button-tertiary-grey button-sm flex-grow flex items-center justify-center",
                "aria-label": action.label,
                children: [
                  action.icon && /* @__PURE__ */ jsx("span", { className: "button-icon mr-2", "aria-hidden": "true", children: action.icon }),
                  /* @__PURE__ */ jsx("span", { className: "button-text", children: action.label })
                ]
              }
            ) }, action.label)) })
          }
        )
      ]
    }
  );
}

// index.ts
var highlight_pop_default = TextHighlightPopup;
export {
  highlight_pop_default as default
};
