import React from 'react';
import { Copy, Clipboard, Highlighter, Bold } from 'lucide-react';
import type { Action } from '../../src/utils/types';
import { toast } from 'sonner';


const copyToClipboard = (text: string) => {
    navigator.clipboard.writeText(text).then(() => {
        toast.success('Text copied to clipboard');
    }).catch(err => {
        toast.error('Failed to copy text', err);
    });
};

const bold = () => {
    const selection = window.getSelection();
    if (selection) {
        const range = selection.getRangeAt(0);
        const span = document.createElement('span');
        span.className = 'bold-text';
        span.style.fontWeight = 'bold';
        range.surroundContents(span);
        toast.success('Text highlighted');
    }
};


const highlight = () => {
    const selection = window.getSelection();
    if (selection) {
        const range = selection.getRangeAt(0);
        const span = document.createElement('span');
        span.className = 'highlighted-text';
        span.style.backgroundColor = 'yellow';
        range.surroundContents(span);
        toast.success('Text highlighted');
    }
}

export const highlightActions: Action[] = [
    {
        label: 'Copy',
        icon: <Copy />,
        action: copyToClipboard,
    },

    {
        label: 'Highlight',
        icon: <Highlighter />,
        action: highlight
    },
    {
        label: 'Bold',
        icon: <Bold />,
        action: bold
    },

];

